from . import mnist
from . import resnet
